@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Fib;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Fib::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Fib - Stress recursion and function calls
 
 # Fibonacci numbers
 
@@ -57,11 +58,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Fib
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Fib - Stress recursion and function calls
+Benchmark::Perl::Formance::Plugin::Fib - benchmark plugin - Fib - Stress recursion and function calls
 
 =head1 AUTHOR
 
