@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::FibMXDeclare;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::FibMXDeclare::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - FibMXDeclare - Stress recursion and method calls (MooseX::Declare)
 
 # Fibonacci numbers
 
@@ -60,11 +61,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::FibMXDeclare
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::FibMXDeclare - Stress recursion and method calls (MooseX::Declare)
+Benchmark::Perl::Formance::Plugin::FibMXDeclare - benchmark plugin - FibMXDeclare - Stress recursion and method calls (MooseX::Declare)
 
 =head1 AUTHOR
 
