@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::FibMoose;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::FibMoose::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - FibMoose - Stress recursion and method calls (Moose)
 
 # Fibonacci numbers
 
@@ -61,11 +62,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::FibMoose
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::FibMoose - Stress recursion and method calls (Moose)
+Benchmark::Perl::Formance::Plugin::FibMoose - benchmark plugin - FibMoose - Stress recursion and method calls (Moose)
 
 =head1 AUTHOR
 
