@@ -2,8 +2,8 @@ package Benchmark::Perl::Formance::Plugin::RxCmp;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::RxCmp::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - RxCmp - Compare different Regex engines
 
-# Compare different Regexes engines plugins (Perl 5.10+)
 
 use 5.010; # [sic - pluggable regex engines]
 use strict;
@@ -271,11 +271,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::RxCmp
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::RxCmp - Compare different Regexes engines plugins (Perl 5.10+)
+Benchmark::Perl::Formance::Plugin::RxCmp - benchmark plugin - RxCmp - Compare different Regex engines
 
 =head1 ABOUT
 
