@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::knucleotide;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::knucleotide::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Shootout::knucleotide - Language shootout plugin: knucleotide
 
 # COMMAND LINE:
 # /usr/bin/perl knucleotide.perl 0 < knucleotide-input25000000.txt
@@ -142,16 +143,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::knucleotide
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Shootout::knucleotide - Language shootout plugin: knucleotide
-
-=head1 ABOUT
-
-This plugin does some runs the "knucleotide" benchmark from the
-Language Shootout.
+Benchmark::Perl::Formance::Plugin::Shootout::knucleotide - benchmark plugin - Shootout::knucleotide - Language shootout plugin: knucleotide
 
 =head1 AUTHOR
 
