@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Shootout::mandelbrot - Language shootout plugin: mandelbrot
 
 # COMMAND LINE:
 # /usr/bin/perl mandelbrot.perl 16000
@@ -128,16 +129,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot - Language shootout plugin: mandelbrot
-
-=head1 ABOUT
-
-This plugin does some runs the "mandelbrot" benchmark from the
-Language Shootout.
+Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot - benchmark plugin - Shootout::mandelbrot - Language shootout plugin: mandelbrot
 
 =head1 AUTHOR
 
