@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::SpamAssassin;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::SpamAssassin::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - SpamAssassin - SpamAssassin Benchmarks
 
 use strict;
 use warnings;
@@ -89,17 +90,15 @@ sub main {
 
 1;
 
+__END__
+
 =pod
 
 =encoding utf-8
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::SpamAssassin
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::SpamAssassin - SpamAssassin Benchmarks
+Benchmark::Perl::Formance::Plugin::SpamAssassin - benchmark plugin - SpamAssassin - SpamAssassin Benchmarks
 
 =head1 ABOUT
 
@@ -123,7 +122,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
-
-time perl -T `which sa-learn` --ham -L --config-file=sa-learn.cfg --prefs-file sa-learn.prefs --dbpath db --no-sync  'easy_ham/*'
